.swagger-section {

.swagger-ui-wrap {

    line-height: 1;
    font-family: "Droid Sans", sans-serif;
    max-width: 960px;
    margin-left: auto;
    margin-right: auto;

    b, strong {
        font-family: "Droid Sans", sans-serif;
        font-weight: bold;
    }

    q, blockquote {
        quotes: none;
    }

    p {
        line-height: 1.4em;
        padding: 0 0 10px;
        color: #333333;
    }

    q:before, q:after, blockquote:before, blockquote:after {
        content: none;
    }

    .heading_with_menu {
        h1, h2, h3, h4, h5, h6 {
            display: block;
            clear: none;
            float: left;
            -moz-box-sizing: border-box;
            -webkit-box-sizing: border-box;
            -ms-box-sizing: border-box;
            box-sizing: border-box;
            width: 60%;
        }
    }

    table {
        border-collapse: collapse;
        border-spacing: 0;
        thead {
            tr {
                th {
                    padding: 5px;
                    font-size: 0.9em;
                    color: #666666;
                    border-bottom: 1px solid #999999;
                }
            }
        }
        tbody {
            tr:last-child {
                td {
                    border-bottom: none;
                }
            }
            tr.offset {
                background-color: #f0f0f0;
            }
            tr {
                td {
                    padding: 6px;
                    font-size: 0.9em;
                    border-bottom: 1px solid #cccccc;
                    vertical-align: top;
                    line-height: 1.3em;
                }
            }
        }
    }

    ol {
        margin: 0px 0 10px;
        padding: 0 0 0 18px;
        list-style-type: decimal;
        li {
            padding: 5px 0px;
            font-size: 0.9em;
            color: #333333;
        }
    }

    ol, ul {
        list-style: none;
    }

    h1, h2, h3, h4, h5, h6 {
        a {
            text-decoration: none;
        }
        a:hover {
            text-decoration: underline;
        }
        span.divider {
            color: #aaaaaa;
        }
    }

    a {
        color: #547f00;
        img {
            border: none;
        }
    }

    article, aside, details, figcaption, figure, footer, header, hgroup, menu, nav, section, summary {
        display: block;
    }

    pre {
        font-family: "Anonymous Pro", "Menlo", "Consolas", "Bitstream Vera Sans Mono", "Courier New", monospace;
        background-color: #fcf6db;
        border: 1px solid #e5e0c6;
        padding: 10px;
        code {
            line-height: 1.6em;
            background: none;
        }
    }

    .content {
        & > .content-type {
            & > div {
                & > label {
                    clear: both;
                    display: block;
                    color: #0F6AB4;
                    font-size: 1.1em;
                    margin: 0;
                    padding: 15px 0 5px;
                }
            }
        }
        pre {
            font-size: 12px;
            margin-top: 5px;
            padding: 5px;
        }
    }

    .icon-btn {
        cursor: pointer;
    }

    .info_title {
        padding-bottom: 10px;
        font-weight: bold;
        font-size: 25px;
    }

    .footer {
        margin-top: 20px;
    }

    p.big, div.big p {
        font-size: 1em;
        margin-bottom: 10px;
    }

    form.fullwidth ol {
        li.string input, li.url input, li.text textarea, li.numeric input {
            width: 500px !important;
        }
    }

    .info_license {
        padding-bottom: 5px;
    }

    .info_tos {
        padding-bottom: 5px;
    }

    .message-fail {
        color: #cc0000;
    }

    .info_url {
        padding-bottom: 5px;
    }

    .info_email {
        padding-bottom: 5px;
    }

    .info_name {
        padding-bottom: 5px;
    }

    .info_description {
        padding-bottom: 10px;
        font-size: 15px;
    }

    .markdown ol li, .markdown ul li {
        padding: 3px 0px;
        line-height: 1.4em;
        color: #333333;
    }

    form.formtastic fieldset.inputs ol {
        li.string input, li.url input, li.numeric input {
            display: block;
            padding: 4px;
            width: auto;
            clear: both;
        }
        li.string input.title,
        li.url input.title,
        li.numeric input.title {
            font-size: 1.3em;
        }
    }

    table.fullwidth {
        width: 100%;
    }

    .model-signature {
        font-family: "Droid Sans", sans-serif;
        font-size: 1em;
        line-height: 1.5em;
        .signature-nav {
            a {
                text-decoration: none;
                color: #AAA;
            }
            a:hover {
                text-decoration: underline;
                color: black;
            }
            .selected {
                color: black;
                text-decoration: none;
            }
        }
        .propType {
            color: #5555aa;
        }
        pre:hover {
            background-color: #ffffdd;
        }
        pre {
            font-size: .85em;
            line-height: 1.2em;
            overflow: auto;
            max-height: 200px;
            cursor: pointer;
        }
        ul.signature-nav {
            display: block;
            margin: 0;
            padding: 0;
            li:last-child {
                padding-right: 0;
                border-right: none;
            }
            li {
                float: left;
                margin: 0 5px 5px 0;
                padding: 2px 5px 2px 0;
                border-right: 1px solid #ddd;
            }
        }
        .propOpt {
            color: #555;
        }
        .snippet {
            small {
                font-size: 0.75em;
            }
        }
        .propOptKey {
            font-style: italic;
        }
        .description {
            .strong {
                font-weight: bold;
                color: #000;
                font-size: .9em;
            }
            div {
                font-size: 0.9em;
                line-height: 1.5em;
                margin-left: 1em;
            }
            .stronger {
                font-weight: bold;
                color: #000;
            }
            .propWrap {
                .optionsWrapper {
                    border-spacing: 0;
                    position: absolute;
                    background-color: #ffffff;
                    border: 1px solid #bbbbbb;
                    display: none;
                    font-size: 11px;
                    max-width: 400px;
                    line-height: 30px;
                    color: black;
                    padding: 5px;
                    margin-left:10px;
                    th {
                        text-align: center;
                        background-color: #eeeeee;
                        border: 1px solid #bbbbbb;
                        font-size: 11px;
                        color: #666666;
                        font-weight: bold;
                        padding: 5px;
                        line-height: 15px;
                    }
                    .optionName {
                        font-weight: bold;
                    }
                }
            }
            .propDesc.markdown {
                > p:first-child,
                > p:last-child {
                    display: inline;
                }
                > p:not(:first-child):before {
                    display: block;
                    content: '';
                }
            }
            span:last-of-type.propDesc.markdown > p:only-child {
                margin-right: -3px; // otherwise there is a gap before the comma
            }
        }
        .propName {
            font-weight: bold;
        }
        .signature-container {
            clear: both;
        }
    }

    .body-textarea {
        width: 300px;
        height: 100px;
        border: 1px solid #aaa;
    }

    .markdown p code, .markdown li code {
        font-family: "Anonymous Pro", "Menlo", "Consolas", "Bitstream Vera Sans Mono", "Courier New", monospace;
        background-color: #f0f0f0;
        color: black;
        padding: 1px 3px;
    }

    .required {
        font-weight: bold;
    }

    /* JSONEditor specific styling */
    .editor_holder {
       font-family: "Anonymous Pro", "Menlo", "Consolas", "Bitstream Vera Sans Mono", "Courier New", monospace;
       font-size: 0.9em;
        label {
            font-weight:normal!important; /* JSONEditor uses bold by default for all labels, we revert that back to normal to not give the impression that by default fields are required */
        }    
    }
    
    .editor_holder label.required {
        font-weight:bold!important; 
    }

    input.parameter {
        width: 300px;
        border: 1px solid #aaa;
    }

    h1 {
        color: black;
        font-size: 1.5em;
        line-height: 1.3em;
        padding: 10px 0 10px 0;
        font-family: "Droid Sans", sans-serif;
        font-weight: bold;
    }

    .heading_with_menu {
        float: none;
        clear: both;
        overflow: hidden;
        display: block;
        ul {
            display: block;
            clear: none;
            float: right;
            -moz-box-sizing: border-box;
            -webkit-box-sizing: border-box;
            -ms-box-sizing: border-box;
            box-sizing: border-box;
            margin-top: 10px;
        }
    }

    h2 {
        color: black;
        font-size: 1.3em;
        padding: 10px 0 10px 0;
        a {
            color: black;
        }
        span.sub {
            font-size: 0.7em;
            color: #999999;
            font-style: italic;
            a {
                color: #777777;
            }
        }
    }

    span.weak {
        color: #666666;
    }

    .message-success {
        color: #89BF04;
    }

    caption, th, td {
        text-align: left;
        font-weight: normal;
        vertical-align: middle;
    }

    .code {
        font-family: "Anonymous Pro", "Menlo", "Consolas", "Bitstream Vera Sans Mono", "Courier New", monospace;
    }

    form.formtastic {
        fieldset.inputs {
            ol {
                li.text {
                    textarea {
                        font-family: "Droid Sans", sans-serif;
                        height: 250px;
                        padding: 4px;
                        display: block;
                        clear: both;
                    }
                }
                li.select {
                    select {
                        display: block;
                        clear: both;
                    }
                }
                li.boolean {
                    float: none;
                    clear: both;
                    overflow: hidden;
                    display: block;
                    label {
                        display: block;
                        float: left;
                        clear: none;
                        margin: 0;
                        padding: 0;
                    }
                    input {
                        display: block;
                        float: left;
                        clear: none;
                        margin: 0 5px 0 0;
                    }
                }
                li.required {
                    label {
                        color: black;
                    }
                }
                li {
                    label {
                        display: block;
                        clear: both;
                        width: auto;
                        padding: 0 0 3px;
                        color: #666666;
                        abbr {
                            padding-left: 3px;
                            color: #888888;
                        }
                    }
                    p.inline-hints {
                        margin-left: 0;
                        font-style: italic;
                        font-size: 0.9em;
                        margin: 0;
                    }
                }
            }
        }
        fieldset.buttons {
            margin: 0;
            padding: 0;
        }
    }

    span.blank, span.empty {
        color: #888888;
        font-style: italic;
    }

    .markdown {
        h3 {
            color: #547f00;
        }
        h4 {
            color: #666666;
        }
        pre {
            font-family: "Anonymous Pro", "Menlo", "Consolas", "Bitstream Vera Sans Mono", "Courier New", monospace;
            background-color: #fcf6db;
            border: 1px solid #e5e0c6;
            padding: 10px;
            margin: 0 0 10px 0;
            code {
                line-height: 1.6em;
            }
        }
    }

    div.gist {
        margin: 20px 0 25px 0 !important;
    }

    ul#resources {
        font-family: "Droid Sans", sans-serif;
        font-size: 0.9em;

        li.resource {
            border-bottom: 1px solid #dddddd;

            &:hover div.heading,
            &.active div.heading {
                h2 a {
                    color: black;
                }
                ul.options li a {
                    color: #555555;
                }
            }

            &:last-child {
                border-bottom: none;
            }

            div.heading {
                border: 1px solid transparent;
                float: none;
                clear: both;
                overflow: hidden;
                display: block;
                ul.options {
                    overflow: hidden;
                    padding: 0;
                    display: block;
                    clear: none;
                    float: right;
                    margin: 14px 10px 0 0;
                    li {
                        float: left;
                        clear: none;
                        margin: 0;
                        padding: 2px 10px;
                        border-right: 1px solid #dddddd;
                        color: #666666;
                        font-size: 0.9em;
                        a {
                            color: #aaaaaa;
                            text-decoration: none;
                        }
                        a:hover {
                            text-decoration: underline;
                            color: black;
                        }
                    }

                    li {
                        a:hover, a:active, a.active {
                            text-decoration: underline;
                        }

                        &:first-child,
                        &.first {
                            padding-left: 0;
                        }

                        &:last-child, &.last {
                            padding-right: 0;
                            border-right: none;
                        }
                    }
                    &:first-child, &.first {
                        padding-left: 0;
                    }
                }
                h2 {
                    color: #999999;
                    padding-left: 0;
                    display: block;
                    clear: none;
                    float: left;
                    font-family: "Droid Sans", sans-serif;
                    font-weight: bold;
                    a {
                        color: #999999;
                    }
                    a:hover {
                        color: black;
                    }
                }
            }
            ul.endpoints {
                li.endpoint {
                    ul.operations {
                        li.operation {
                            float: none;
                            clear: both;
                            overflow: hidden;
                            display: block;
                            margin: 0 0 10px;
                            padding: 0;
                            div.heading {
                                float: none;
                                clear: both;
                                overflow: hidden;
                                display: block;
                                margin: 0;
                                padding: 0;
                                h3 {
                                    display: block;
                                    clear: none;
                                    float: left;
                                    width: auto;
                                    margin: 0;
                                    padding: 0;
                                    line-height: 1.1em;
                                    color: black;
                                    span.path {
                                        padding-left: 10px;
                                        a {
                                            color: black;
                                            text-decoration: none;
                                        }
                                        a:hover {
                                            text-decoration: underline;
                                        }
                                    }
                                    span.http_method {
                                        a {
                                            text-transform: uppercase;
                                            text-decoration: none;
                                            color: white;
                                            display: inline-block;
                                            width: 50px;
                                            font-size: 0.7em;
                                            text-align: center;
                                            padding: 7px 0 4px;
                                            -moz-border-radius: 2px;
                                            -webkit-border-radius: 2px;
                                            -o-border-radius: 2px;
                                            -ms-border-radius: 2px;
                                            -khtml-border-radius: 2px;
                                            border-radius: 2px;
                                        }
                                    }
                                    span {
                                        margin: 0;
                                        padding: 0;
                                    }
                                }
                                ul.options {
                                    overflow: hidden;
                                    padding: 0;
                                    display: block;
                                    clear: none;
                                    float: right;
                                    margin: 6px 10px 0 0;
                                    li {
                                        float: left;
                                        clear: none;
                                        margin: 0;
                                        padding: 2px 10px;
                                        font-size: 0.9em;
                                        a {
                                            text-decoration: none;
                                        }
                                    }
                                }
                                ul.options {
                                    li.access {
                                        color: black;
                                    }
                                }
                            }
                            div.content {
                                border-top: none;
                                padding: 10px;
                                -moz-border-radius-bottomleft: 6px;
                                -webkit-border-bottom-left-radius: 6px;
                                -o-border-bottom-left-radius: 6px;
                                -ms-border-bottom-left-radius: 6px;
                                -khtml-border-bottom-left-radius: 6px;
                                border-bottom-left-radius: 6px;
                                -moz-border-radius-bottomright: 6px;
                                -webkit-border-bottom-right-radius: 6px;
                                -o-border-bottom-right-radius: 6px;
                                -ms-border-bottom-right-radius: 6px;
                                -khtml-border-bottom-right-radius: 6px;
                                border-bottom-right-radius: 6px;
                                margin: 0 0 20px;
                                h4 {
                                    font-size: 1.1em;
                                    margin: 0;
                                    padding: 15px 0 5px;
                                }
                                div.sandbox_header {
                                    float: none;
                                    clear: both;
                                    overflow: hidden;
                                    display: block;
                                    a {
                                        padding: 4px 0 0 10px;
                                        display: inline-block;
                                        font-size: 0.9em;
                                    }
                                    input.submit {
                                        display: block;
                                        clear: none;
                                        float: left;
                                        padding: 6px 8px;
                                    }
                                    span.response_throbber {
                                      background-image: url('../images/throbber.gif');
                                      width: 128px;
                                      height: 16px;
                                      display: block;
                                      clear: none;
                                      float: right;
                                    }
                                }
                                form {
                                    input[type='text'].error {
                                        outline: 2px solid black;
                                        outline-color: #cc0000;
                                    }
                                    select[name='parameterContentType'] {
                                        max-width:300px;
                                    }
                                }
                                div.response {
                                    div.block {
                                        pre {
                                            font-family: "Anonymous Pro", "Menlo", "Consolas", "Bitstream Vera Sans Mono", "Courier New", monospace;
                                            padding: 10px;
                                            font-size: 0.9em;
                                            max-height: 400px;
                                            overflow-y: auto;
                                        }
                                    }
                                }
                            }
                        }
                        li.operation.put {
                            div.heading {
                                background-color: #f9f2e9;
                                border: 1px solid #f0e0ca;
                                h3 {
                                    span.http_method {
                                        a {
                                            background-color: #c5862b;
                                        }
                                    }
                                }
                                ul.options {
                                    li {
                                        border-right: 1px solid #dddddd;
                                        border-right-color: #f0e0ca;
                                        color: #c5862b;
                                        a {
                                            color: #c5862b;
                                        }
                                    }
                                }
                            }
                            div.content {
                                background-color: #faf5ee;
                                border: 1px solid #f0e0ca;
                                h4 {
                                    color: #c5862b;
                                }
                                div.sandbox_header {
                                    a {
                                        color: #dcb67f;

                                    }
                                }
                            }
                        }
                        li.operation.head {
                            div.heading {
                                background-color: #fcffcd;
                                border: 1px solid black;
                                border-color: #ffd20f;
                                h3 {
                                    span.http_method {
                                        a {
                                            text-transform: uppercase;
                                            background-color: #ffd20f;
                                        }
                                    }
                                }
                                ul.options {
                                    li {
                                        border-right: 1px solid #dddddd;
                                        border-right-color: #ffd20f;
                                        color: #ffd20f;
                                        a {
                                            color: #ffd20f;
                                        }
                                    }
                                }
                            }
                            div.content {
                                background-color: #fcffcd;
                                border: 1px solid black;
                                border-color: #ffd20f;
                                h4 {
                                    color: #ffd20f;
                                }
                                div.sandbox_header {
                                    a {
                                        color: #6fc992;
                                    }
                                }
                            }
                        }
                        li.operation.delete {
                            div.heading {
                                background-color: #f5e8e8;
                                border: 1px solid #e8c6c7;
                                h3 {
                                    span.http_method {
                                        a {
                                            text-transform: uppercase;
                                            background-color: #a41e22;

                                        }
                                    }
                                }
                                ul.options {
                                    li {
                                        border-right: 1px solid #dddddd;
                                        border-right-color: #e8c6c7;
                                        color: #a41e22;
                                        a {
                                            color: #a41e22;
                                        }
                                    }
                                }
                            }
                            div.content {
                                background-color: #f7eded;
                                border: 1px solid #e8c6c7;
                                h4 {
                                    color: #a41e22;
                                }
                                div.sandbox_header {
                                    a {
                                        color: #c8787a;
                                    }
                                }
                            }
                        }
                        li.operation.post {
                            div.heading {
                                background-color: #e7f6ec;
                                border: 1px solid #c3e8d1;
                                h3 {
                                    span.http_method {
                                        a {
                                            background-color: #10a54a;
                                        }
                                    }
                                }
                                ul.options {
                                    li {
                                        border-right: 1px solid #dddddd;
                                        border-right-color: #c3e8d1;
                                        color: #10a54a;
                                        a {
                                            color: #10a54a;
                                        }
                                    }
                                }
                            }
                            div.content {
                                background-color: #ebf7f0;
                                border: 1px solid #c3e8d1;
                                h4 {
                                    color: #10a54a;
                                }
                                div.sandbox_header {
                                    a {
                                        color: #6fc992;
                                    }
                                }
                            }
                        }
                        li.operation.patch {
                            div.heading {
                                background-color: #FCE9E3;
                                border: 1px solid #F5D5C3;
                                h3 {
                                    span.http_method {
                                        a {
                                            background-color: #D38042;

                                        }
                                    }
                                }
                                ul.options {
                                    li {
                                        border-right: 1px solid #dddddd;
                                        border-right-color: #f0cecb;
                                        color: #D38042;
                                        a {
                                            color: #D38042;
                                        }
                                    }
                                }
                            }
                            div.content {
                                background-color: #faf0ef;
                                border: 1px solid #f0cecb;

                                h4 {
                                    color: #D38042;

                                }
                                div.sandbox_header {
                                    a {
                                        color: #dcb67f;
                                    }
                                }
                            }
                        }
                        li.operation.get {
                            div.heading {
                                background-color: #e7f0f7;
                                border: 1px solid #c3d9ec;
                                h3 {
                                    span.http_method {
                                        a {
                                            background-color: #0f6ab4;
                                        }
                                    }
                                }
                                ul.options {
                                    li {
                                        border-right: 1px solid #dddddd;
                                        border-right-color: #c3d9ec;
                                        color: #0f6ab4;
                                        a {
                                            color: #0f6ab4;
                                        }
                                    }
                                }
                            }
                            div.content {
                                background-color: #ebf3f9;
                                border: 1px solid #c3d9ec;
                                h4 {
                                    color: #0f6ab4;
                                }
                                div.sandbox_header {
                                    a {
                                        color: #6fa5d2;
                                    }
                                }
                            }
                        }
                        li.operation.options {
                            div.heading {
                                background-color: #e7f0f7;
                                border: 1px solid #c3d9ec;
                                h3 {
                                    span.http_method {
                                        a {
                                            background-color: #0f6ab4;
                                        }
                                    }
                                }
                                ul.options {
                                    li {
                                        border-right: 1px solid #dddddd;
                                        border-right-color: #c3d9ec;
                                        color: #0f6ab4;
                                        a {
                                            color: #0f6ab4;
                                        }
                                    }
                                }
                            }
                            div.content {
                                background-color: #ebf3f9;
                                border: 1px solid #c3d9ec;
                                h4 {
                                    color: #0f6ab4;
                                }
                                div.sandbox_header {
                                    a {
                                        color: #6fa5d2;
                                    }
                                }
                            }
                        }
                        li.operation {
                            &.get, &.post, &.head, &.put, &.patch, &.delete {
                                div.content {
                                    border-top: none;
                                }
                                div.heading ul.options li {
                                    &:last-child, &.last {
                                        padding-right: 0;
                                        border-right: none;
                                    }
                                }
                            }
                        }
                        ul.options li {
                            a:hover, a:active, a.active {
                                text-decoration: underline;
                            }

                            &:first-child,
                            &.first {
                                padding-left: 0;
                            }

                        }
                        &:first-child, &.first {
                            padding-left: 0;
                        }
                    }
                }
            }
        }
    }

    p#colophon {
        margin: 0 15px 40px 15px;
        padding: 10px 0;
        font-size: 0.8em;
        border-top: 1px solid #dddddd;
        font-family: "Droid Sans", sans-serif;
        color: #999999;
        font-style: italic;
        a {
            text-decoration: none;
            color: #547f00;
        }
    }

    h3 {
        color: black;
        font-size: 1.1em;
        padding: 10px 0 10px 0;
    }

    .markdown ol, .markdown ul {
        font-family: "Droid Sans", sans-serif;
        margin: 5px 0 10px;
        padding: 0 0 0 18px;
        list-style-type: disc;
    }

    form.form_box {
        background-color: #ebf3f9;
        border: 1px solid #c3d9ec;
        padding: 10px;
        label {
            color: #0f6ab4 !important;
        }
        input[type=submit] {
            display: block;
            padding: 10px;
        }
        p.weak {
            font-size: 0.8em;
        }
        p {
            font-size: 0.9em;
            padding: 0 0 15px;
            color: #7e7b6d;
            a {
                color: #646257;
            }
            strong {
                color: black;
            }
        }
    }

    .operation-status td.markdown > p:last-child {
        padding-bottom: 0;
    }
}

}
