

@import 'src/main/less/highlight_default.less';
@import 'src/main/less/specs.less';
@import 'src/main/less/auth.less';

.swagger-section {

  .access { float: right; }

  .auth { float: right; }

  .api-ic {
    height: 18px;
    vertical-align: middle;
    display: inline-block;
    background: url(../images/explorer_icons.png) no-repeat;
  }

  .api-ic .api_information_panel {
    position: relative;
    margin-top: 20px;
    margin-left: -5px;
    background: #FFF;
    border: 1px solid #ccc;
    border-radius: 5px;
    display: none;
    font-size: 13px;
    max-width: 300px;
    line-height: 30px;
    color: black;
    padding: 5px;
  }

  .api-ic .api_information_panel p .api-msg-enabled { color: green; }
  .api-ic .api_information_panel p .api-msg-disabled { color: red; }

  .api-ic:hover .api_information_panel {
    position: absolute;
    display: block;
  }

  .ic-info {
    background-position: 0 0;
    width: 18px;
    margin-top: -6px;
    margin-left: 4px;
  }

  .ic-warning {
    background-position: -60px 0;
    width: 18px;
    margin-top: -6px;
    margin-left: 4px;
  }

  .ic-error {
    background-position: -30px 0;
    width: 18px;
    margin-top: -6px;
    margin-left: 4px;
  }

  .ic-off {
    background-position: -90px 0;
    width: 58px;
    margin-top: -4px;
    cursor: pointer;
  }

  .ic-on {
    background-position: -160px 0;
    width: 58px;
    margin-top: -4px;
    cursor: pointer;
  }

  #header {
    background-color: #89bf04;
    padding: 14px;
  }

  #input_baseUrl { width: 400px; }

  #api_selector {
    display: block;
    clear: none;
    float: right;
  }

  #api_selector .input {
    display: block;
    clear: none;
    float: left;
    margin: 0 10px 0 0;
  }

  #api_selector input {
    font-size: 0.9em;
    padding: 3px;
    margin: 0;
  }

  #input_apiKey { width: 200px; }

  #explore {
    display: block;
    text-decoration: none;
    font-weight: bold;
    padding: 6px 8px;
    font-size: 0.9em;
    color: white;
    background-color: #547f00;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    -o-border-radius: 4px;
    -ms-border-radius: 4px;
    -khtml-border-radius: 4px;
    border-radius: 4px;

    &:hover { background-color: #547f00; }
  }

  #header #logo {
    font-size: 1.5em;
    font-weight: bold;
    text-decoration: none;
    background: transparent url(../images/logo_small.png) no-repeat left center;
    padding: 20px 0 20px 40px;
    color: white;
  }

  #content_message {
    margin: 10px 15px;
    font-style: italic;
    color: #999999;
  }

  #message-bar {
    min-height: 30px;
    text-align: center;
    padding-top: 10px;
  }
  
  .swagger-collapse:before {
    content: "-";
  }

  .swagger-expand:before {
    content: "+";
  }

}






