

.swagger-section {

  .title { font-style: bold; }

  .secondary_form { display: none; }

  .main_image {
    display: block;
    margin-left: auto;
    margin-right: auto;
  }

  .oauth_body {
    margin-left: 100px;
    margin-right: 100px;
  }

  .oauth_submit { text-align: center; }

  .api-popup-dialog {
    z-index: 10000;
    position: absolute;
    width: 500px;
    background: #FFF;
    padding: 20px;
    border: 1px solid #ccc;
    border-radius: 5px;
    display: none;
    font-size: 13px;
    color: #777;
  }

  .api-popup-dialog .api-popup-title {
    font-size: 24px;
    padding: 10px 0;
  }

  .api-popup-dialog .api-popup-title {
    font-size: 24px;
    padding: 10px 0;
  }

  .api-popup-dialog .error-msg {
    padding-left: 5px;
    padding-bottom: 5px;
  }

  .api-popup-dialog .api-popup-authbtn { height: 30px; }

  .api-popup-dialog .api-popup-cancel { height: 30px; }

  .api-popup-scopes { padding: 10px 20px; }

  .api-popup-scopes li {
    padding: 5px 0;
    line-height: 20px;
  }

  .api-popup-scopes li input {
    position: relative;
    top: 2px;
  }

  .api-popup-scopes .api-scope-desc {
    padding-left: 20px;
    font-style: italic;
  }

  .api-popup-actions { padding-top: 10px; }
}
